
Scripts, tests and other modules
================================

.. autosummary:: 
   :toctree: autogen
   :nosignatures:

   polyfemos.almanac.ordinal
   polyfemos.almanac.timer
   polyfemos.almanac.utils
   polyfemos.data.outlierremover
   polyfemos.data.statistics
   polyfemos.data.utils
   polyfemos.parser.filepathparser
   polyfemos.parser.functionparser
   polyfemos.parser.resources
   polyfemos.parser.typeoperator
   polyfemos.scripts.check_output_files
   polyfemos.scripts.devserver
   polyfemos.scripts.render_web_templates
   polyfemos.scripts.test_front_paths
   polyfemos.scripts.sohemailer
   polyfemos.tests.test_python_packages
   polyfemos.util.coordinator
   polyfemos.util.fileutils
   polyfemos.util.messenger
   polyfemos.util.randomizer

